==> xid_xpl-0.0.17.tar.gz: xid_xpl-0.0.17/src/xpl/container/dictionary.py <==
#--------------------------------------------------------------------------------
# 참조 모듈 목록.
#--------------------------------------------------------------------------------
from __future__ import annotations
from typing import Awaitable, Callable, Final, Generic, Iterable, Iterator, Optional, Sequence, Type, TypeVar, Tuple, Union
from typing import ItemsView, KeysView, ValuesView
from typing import Any, List, Dict, Set
from typing import cast, overload


#--------------------------------------------------------------------------------
# 제네릭 딕셔너리.
#--------------------------------------------------------------------------------
TKey = TypeVar("TKey", bound = Any)
TValue = TypeVar("TValue", bound = Any)
class Dictionary(Generic[TKey, TValue]):
	#--------------------------------------------------------------------------------
	# 멤버 변수 목록.
	#--------------------------------------------------------------------------------
	__dictionary: dict[TKey, TValue]


	#--------------------------------------------------------------------------------
	# 초기화 라이프사이클 메서드.
	#--------------------------------------------------------------------------------
	def __init__(self) -> None:
		self.__dictionary = dict()


	#--------------------------------------------------------------------------------
	# 값 넣기.
	#--------------------------------------------------------------------------------
	def __setitem__(self, key: TKey, value: TValue) -> None:
		self.__dictionary[TKey] = value


	#--------------------------------------------------------------------------------
	# 값 반환.
	#--------------------------------------------------------------------------------
	def __getitem__(self, key: TKey) -> TValue:
		if key not in self.__dictionary:
			raise KeyError(key)
		return self.__dictionary[key]


	#--------------------------------------------------------------------------------
	# 클래스 시리얼라이즈.
	#--------------------------------------------------------------------------------
	def __repr__(self) -> str:
		return repr(self.__dictionary)


	#--------------------------------------------------------------------------------
	# 키 목록 반환.
	#--------------------------------------------------------------------------------
	def keys(self) -> KeysView[TKey]:
		return self.__dictionary.keys()


	#--------------------------------------------------------------------------------
	# 값 목록 반환.
	#--------------------------------------------------------------------------------
	def values(self) -> ValuesView[TValue]:
		return self.__dictionary.values()


	#--------------------------------------------------------------------------------
	# 요소 반환.
	#--------------------------------------------------------------------------------
	def items(self) -> ItemsView[TKey, TValue]:
		return self.__dictionary.items()


	#--------------------------------------------------------------------------------
	# 갯수 반환.
	#--------------------------------------------------------------------------------
	def __len__(self) -> int:
		return len(self.__dictionary)


	#--------------------------------------------------------------------------------
	# 포함 여부 반환.
	#--------------------------------------------------------------------------------
	def __contains__(self, key: TKey) -> bool:
		return key in self.__dictionary

==> xid_xpl-0.0.21.tar.gz: xid_xpl-0.0.21/src/xpl/container/dictionary.py <==
#--------------------------------------------------------------------------------
# 참조 모듈 목록.
#--------------------------------------------------------------------------------
from __future__ import annotations
from typing import Awaitable, Callable, Final, Generic, Iterable, Iterator, Optional, Sequence, Type, TypeVar, Tuple, Union
from typing import ItemsView, KeysView, ValuesView
from typing import Any, List, Dict, Set
from typing import cast, overload


#--------------------------------------------------------------------------------
# 제네릭 딕셔너리.
#--------------------------------------------------------------------------------
TKey = TypeVar("TKey", bound = Any)
TValue = TypeVar("TValue", bound = Any)
class Dictionary(Generic[TKey, TValue]):
	#--------------------------------------------------------------------------------
	# 멤버 변수 목록.
	#--------------------------------------------------------------------------------
	__dictionary: dict[TKey, TValue]


	#--------------------------------------------------------------------------------
	# 초기화 라이프사이클 메서드.
	#--------------------------------------------------------------------------------
	def __init__(thisInstance) -> None:
		thisInstance.__dictionary = dict()


	#--------------------------------------------------------------------------------
	# 값 넣기.
	#--------------------------------------------------------------------------------
	def __setitem__(thisInstance, key: TKey, value: TValue) -> None:
		thisInstance.__dictionary[TKey] = value


	#--------------------------------------------------------------------------------
	# 값 반환.
	#--------------------------------------------------------------------------------
	def __getitem__(thisInstance, key: TKey) -> TValue:
		if key not in thisInstance.__dictionary:
			raise KeyError(key)
		return thisInstance.__dictionary[key]


	#--------------------------------------------------------------------------------
	# 클래스 시리얼라이즈.
	#--------------------------------------------------------------------------------
	def __repr__(thisInstance) -> str:
		return repr(thisInstance.__dictionary)


	#--------------------------------------------------------------------------------
	# 키 목록 반환.
	#--------------------------------------------------------------------------------
	def keys(thisInstance) -> KeysView[TKey]:
		return thisInstance.__dictionary.keys()


	#--------------------------------------------------------------------------------
	# 값 목록 반환.
	#--------------------------------------------------------------------------------
	def values(thisInstance) -> ValuesView[TValue]:
		return thisInstance.__dictionary.values()


	#--------------------------------------------------------------------------------
	# 요소 반환.
	#--------------------------------------------------------------------------------
	def items(thisInstance) -> ItemsView[TKey, TValue]:
		return thisInstance.__dictionary.items()


	#--------------------------------------------------------------------------------
	# 갯수 반환.
	#--------------------------------------------------------------------------------
	def __len__(thisInstance) -> int:
		return len(thisInstance.__dictionary)


	#--------------------------------------------------------------------------------
	# 포함 여부 반환.
	#--------------------------------------------------------------------------------
	def __contains__(thisInstance, key: TKey) -> bool:
		return key in thisInstance.__dictionary
